#[non_exhaustive]pub enum HookOutcome {
Continue,
Reject {
reason: String,
},
}Expand description
Outcome of a host-side hook invocation.
Hooks may continue normally, request a rewrite of the operation, or reject the operation outright with a reason.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations