MemoryPersistence

Struct MemoryPersistence 

pub struct MemoryPersistence;
In-memory SchedulerPersistence backend. Always returns an empty load_all; every other call is a no-op.

Used by tests and as the default backend when the host has not yet wired a durable backend (e.g., during early Uni::build before the storage manager is available).